# SearchSource: OpenLibrary

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[OpenLibrary](https://openlibrary.org/)

## Add the search source

Searches of the OpenLibrary are not (yet) supported.

## Links
